==> dhall-lsp-server-1.1.4-90-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-CrBsIjIMcubDsjJomaQb3a
key:                  dhall-lsp-server-1.1.4-CrBsIjIMcubDsjJomaQb3a
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  ec47c5d3f5dd77caba87f703018f19d2
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-CrBsIjIMcubDsjJomaQb3a
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-3ZAPJG8B8UQLXQ3UK4qwOj
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dhall-1.42.3-6ivmxcjn5ctBDS3CQUifdU
    dhall-json-1.7.12-DNkntXMNk15AAJ0w8mbM6T directory-1.3.8.5
    filepath-1.4.300.1 lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2
    text-rope-0.3-7UnKSGc2q389N6WPFXjNKl transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uri-encode-1.5.0.7-7znw3Txb6UEDNB9RHayVJK

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-lsp-server-1.1.4-95-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-1dPIBXvx727Ivb1aTLZCw1
key:                  dhall-lsp-server-1.1.4-1dPIBXvx727Ivb1aTLZCw1
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  0fd5beec655320ad2844c7559b44f4d3
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-1dPIBXvx727Ivb1aTLZCw1
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    aeson-pretty-0.8.10-eT1JM8BphwIKZ7kNgAtSZ base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-E4gc6H4PEp9IHp9m40mldi
    containers-0.6.7 data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl
    dhall-1.42.3-EidAGmin8lt7mPY3yHO1CI
    dhall-json-1.7.12-8jxhcocVQAaBGx0D22Ooi directory-1.3.8.5
    filepath-1.4.300.1 lens-5.3.3-KFcjpRU85K93uhgNXhcmM2
    lsp-2.2.0.0-8xJnLrvCaqxFP1VN2WNi9Q
    megaparsec-9.7.0-EBrXuyfSuyTIUi7T8Ua8UQ mtl-2.3.1
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w text-2.0.2
    text-rope-0.3-6zt0Bl1qaiA4JrZ8EyvLQB transformers-0.6.1.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    uri-encode-1.5.0.7-CT2KNW13eeQ6FPn3O7IksB

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
